==> jc-1.4.0.tar.gz: java/awt/ComponentOrientation.h <==
// public final class java.awt.ComponentOrientation

// class file dependencies
// @dep_class 9fec2c09b29a5101 java_awt_ComponentOrientation
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_ComponentOrientation_H_
#define _JC_java_awt_ComponentOrientation_H_

// Forward structure declarations
struct _jc_java_awt_ComponentOrientation$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_Locale$object;
struct _jc_java_util_ResourceBundle$object;

// Typedefs
typedef struct _jc_java_awt_ComponentOrientation$sub_refs	_jc_java_awt_ComponentOrientation$sub_refs;
typedef struct _jc_java_awt_ComponentOrientation$sub_nonrefs	_jc_java_awt_ComponentOrientation$sub_nonrefs;
typedef struct _jc_java_awt_ComponentOrientation$refs	_jc_java_awt_ComponentOrientation$refs;
typedef struct _jc_java_awt_ComponentOrientation$nonrefs	_jc_java_awt_ComponentOrientation$nonrefs;
typedef struct _jc_java_awt_ComponentOrientation$object	_jc_java_awt_ComponentOrientation$object;

typedef struct _jc_java_awt_ComponentOrientation$fields_struct	_jc_java_awt_ComponentOrientation$fields_struct;
typedef const struct _jc_java_awt_ComponentOrientation$vmethods	_jc_java_awt_ComponentOrientation$vmethods;
typedef const struct _jc_java_awt_ComponentOrientation$vtable	_jc_java_awt_ComponentOrientation$vtable;
typedef const struct _jc_java_awt_ComponentOrientation$vtype	_jc_java_awt_ComponentOrientation$vtype;

// Class fields structure
struct _jc_java_awt_ComponentOrientation$fields_struct {
	struct _jc_java_awt_ComponentOrientation$object	*LEFT__5fTO__5fRIGHT;
	struct _jc_java_awt_ComponentOrientation$object	*RIGHT__5fTO__5fLEFT;
	struct _jc_java_awt_ComponentOrientation$object	*UNKNOWN;
	jlong	serialVersionUID;
	jint	HORIZONTAL__5fID;
	jint	LEFT__5fTO__5fRIGHT__5fID;
	jint	UNKNOWN__5fID;
};
extern _jc_java_awt_ComponentOrientation$fields_struct _jc_java_awt_ComponentOrientation$class_fields;

// Constructors
extern void _jc_java_awt_ComponentOrientation$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_awt_ComponentOrientation$object *, jint);

// Virtual methods
extern jboolean _jc_java_awt_ComponentOrientation$method$isHorizontal$725148ec3037af97(_jc_env *, struct _jc_java_awt_ComponentOrientation$object *);
extern jboolean _jc_java_awt_ComponentOrientation$method$isLeftToRight$124cc0d52ee34b2a(_jc_env *, struct _jc_java_awt_ComponentOrientation$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_ComponentOrientation$method_info$isHorizontal$725148ec3037af97;
extern _jc_method _jc_java_awt_ComponentOrientation$method_info$isLeftToRight$124cc0d52ee34b2a;

// Static methods
extern void _jc_java_awt_ComponentOrientation$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_awt_ComponentOrientation$object *_jc_java_awt_ComponentOrientation$method$getOrientation$cf8119f221140982(_jc_env *, struct _jc_java_util_Locale$object *);
extern struct _jc_java_awt_ComponentOrientation$object *_jc_java_awt_ComponentOrientation$method$getOrientation$e17bbc4157b9d1e7(_jc_env *, struct _jc_java_util_ResourceBundle$object *);

// Virtual methods structure
struct _jc_java_awt_ComponentOrientation$vmethods {
	jboolean	(*isHorizontal$725148ec3037af97)(_jc_env *, struct _jc_java_awt_ComponentOrientation$object *);
	jboolean	(*isLeftToRight$124cc0d52ee34b2a)(_jc_env *, struct _jc_java_awt_ComponentOrientation$object *);
};

// Vtable
struct _jc_java_awt_ComponentOrientation$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_ComponentOrientation$vmethods	java_awt_ComponentOrientation;
};

// Vtype
struct _jc_java_awt_ComponentOrientation$vtype {
	_jc_type			type;
	_jc_java_awt_ComponentOrientation$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_ComponentOrientation$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_ComponentOrientation$refs {
    _jc_java_awt_ComponentOrientation$sub_refs	java_awt_ComponentOrientation;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_ComponentOrientation$sub_nonrefs {
	jint	orientation;
};

// Non-reference instance fields (object)
struct _jc_java_awt_ComponentOrientation$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_ComponentOrientation$sub_nonrefs	java_awt_ComponentOrientation;
};

// Object instance structure
struct _jc_java_awt_ComponentOrientation$object {
	_jc_java_awt_ComponentOrientation$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_ComponentOrientation$vtype	*vtype;
	_jc_java_awt_ComponentOrientation$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_ComponentOrientation$vtype _jc_java_awt_ComponentOrientation$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_ComponentOrientation, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_ComponentOrientation$class_object;

#endif	/* _JC_java_awt_ComponentOrientation_H_ */

==> jc-1.4.6.tar.gz: java/awt/ComponentOrientation.h <==
// public final class java.awt.ComponentOrientation

// class file dependencies
// @dep_class 9fec2c09b29a5101 java_awt_ComponentOrientation
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_ComponentOrientation_H_
#define _JC_java_awt_ComponentOrientation_H_

// Forward structure declarations
struct _jc_java_awt_ComponentOrientation$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_Locale$object;
struct _jc_java_util_ResourceBundle$object;

// Typedefs
typedef struct _jc_java_awt_ComponentOrientation$sub_refs	_jc_java_awt_ComponentOrientation$sub_refs;
typedef struct _jc_java_awt_ComponentOrientation$sub_nonrefs	_jc_java_awt_ComponentOrientation$sub_nonrefs;
typedef struct _jc_java_awt_ComponentOrientation$refs	_jc_java_awt_ComponentOrientation$refs;
typedef struct _jc_java_awt_ComponentOrientation$nonrefs	_jc_java_awt_ComponentOrientation$nonrefs;
typedef struct _jc_java_awt_ComponentOrientation$object	_jc_java_awt_ComponentOrientation$object;

typedef struct _jc_java_awt_ComponentOrientation$fields_struct	_jc_java_awt_ComponentOrientation$fields_struct;
typedef const struct _jc_java_awt_ComponentOrientation$vmethods	_jc_java_awt_ComponentOrientation$vmethods;
typedef const struct _jc_java_awt_ComponentOrientation$vtable	_jc_java_awt_ComponentOrientation$vtable;
typedef const struct _jc_java_awt_ComponentOrientation$vtype	_jc_java_awt_ComponentOrientation$vtype;

// Class fields structure
struct _jc_java_awt_ComponentOrientation$fields_struct {
	struct _jc_java_awt_ComponentOrientation$object	*LEFT__5fTO__5fRIGHT;
	struct _jc_java_awt_ComponentOrientation$object	*RIGHT__5fTO__5fLEFT;
	struct _jc_java_awt_ComponentOrientation$object	*UNKNOWN;
	jlong	serialVersionUID;
	jint	HORIZONTAL__5fID;
	jint	LEFT__5fTO__5fRIGHT__5fID;
	jint	UNKNOWN__5fID;
};
extern _jc_java_awt_ComponentOrientation$fields_struct _jc_java_awt_ComponentOrientation$class_fields;

// Constructors
extern void _jc_java_awt_ComponentOrientation$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_awt_ComponentOrientation$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_awt_ComponentOrientation$method$isHorizontal$725148ec3037af97(_jc_env *, struct _jc_java_awt_ComponentOrientation$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_awt_ComponentOrientation$method$isLeftToRight$124cc0d52ee34b2a(_jc_env *, struct _jc_java_awt_ComponentOrientation$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_ComponentOrientation$method_info$isHorizontal$725148ec3037af97;
extern _jc_method _jc_java_awt_ComponentOrientation$method_info$isLeftToRight$124cc0d52ee34b2a;

// Static methods
extern void _jc_java_awt_ComponentOrientation$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_ComponentOrientation$object *_jc_java_awt_ComponentOrientation$method$getOrientation$cf8119f221140982(_jc_env *, struct _jc_java_util_Locale$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_ComponentOrientation$object *_jc_java_awt_ComponentOrientation$method$getOrientation$e17bbc4157b9d1e7(_jc_env *, struct _jc_java_util_ResourceBundle$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_awt_ComponentOrientation$vmethods {
	jboolean	(*isHorizontal$725148ec3037af97)(_jc_env *, struct _jc_java_awt_ComponentOrientation$object *) _JC_JCNI_ATTR;
	jboolean	(*isLeftToRight$124cc0d52ee34b2a)(_jc_env *, struct _jc_java_awt_ComponentOrientation$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_ComponentOrientation$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_ComponentOrientation$vmethods	java_awt_ComponentOrientation;
};

// Vtype
struct _jc_java_awt_ComponentOrientation$vtype {
	_jc_type			type;
	_jc_java_awt_ComponentOrientation$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_ComponentOrientation$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_ComponentOrientation$refs {
    _jc_java_awt_ComponentOrientation$sub_refs	java_awt_ComponentOrientation;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_ComponentOrientation$sub_nonrefs {
	jint	orientation;
};

// Non-reference instance fields (object)
struct _jc_java_awt_ComponentOrientation$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_ComponentOrientation$sub_nonrefs	java_awt_ComponentOrientation;
};

// Object instance structure
struct _jc_java_awt_ComponentOrientation$object {
	_jc_java_awt_ComponentOrientation$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_ComponentOrientation$vtype	*vtype;
	_jc_java_awt_ComponentOrientation$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_ComponentOrientation$vtype _jc_java_awt_ComponentOrientation$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_ComponentOrientation, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_ComponentOrientation$class_object;

#endif	/* _JC_java_awt_ComponentOrientation_H_ */
